@@ -23,31 +23,51 @@ Lingua::EN::Sentence - Module for splitting text into sentences.
 
 =head1 DESCRIPTION
 
-The C<Lingua::EN::Sentence> module contains the function get_sentences, which splits text into its constituent sentences, based on a regular expression and a list of abbreviations (built in and given).
+The C<Lingua::EN::Sentence> module contains the function get_sentences, which
+splits text into its constituent sentences, based on a regular expression and a
+list of abbreviations (built in and given).
 
-Certain well know exceptions, such as abreviations, may cause incorrect segmentations.  But some of them are already integrated into this code and are being taken care of.  Still, if you see that there are words causing the get_sentences() to fail, you can add those to the module, so it notices them.
+Certain well know exceptions, such as abreviations, may cause incorrect
+segmentations. But some of them are already integrated into this code and are
+being taken care of. Still, if you see that there are words causing the
+get_sentences() to fail, you can add those to the module, so it notices them.
 
 =head1 ALGORITHM
 
-Basically, I use a 'brute' regular expression to split the text into sentences.  (Well, nothing is yet split - I just mark the end-of-sentence).  Then I look into a set of rules which decide when an end-of-sentence is justified and when it's a mistake. In case of a mistake, the end-of-sentence mark is removed. 
+Basically, I use a 'brute' regular expression to split the text into sentences.
+(Well, nothing is yet split - I just mark the end-of-sentence). Then I look into
+a set of rules which decide when an end-of-sentence is justified and when it's a
+mistake. In case of a mistake, the end-of-sentence mark is removed.
 
-What are such mistakes? Cases of abbreviations, for example. I have a list of such abbreviations (Please see `Acronym/Abbreviations list' section), and more general rules (for example, the abbreviations 'i.e.' and '.e.g.' need not to be in the list as a special rule takes care of all single letter abbreviations).
+What are such mistakes? Cases of abbreviations, for example. I have a list of
+such abbreviations (Please see `Acronym/Abbreviations list' section), and more
+general rules (for example, the abbreviations 'i.e.' and '.e.g.' need not to be
+in the list as a special rule takes care of all single letter abbreviations).
 
 =head1 FUNCTIONS
 
-All functions used should be requested in the 'use' clause. None is exported by default.
+All functions used should be requested in the 'use' clause. None is exported by
+default.
+
+=over 4
 
 =item get_sentences( $text )
 
-The get sentences function takes a scalar containing ascii text as an argument and returns a reference to an array of sentences that the text has been split into.
-Returned sentences will be trimmed (beginning and end of sentence) of white-spaces.
-Strings with no alpha-numeric characters in them, won't be returned as sentences.
+The get_sentences function takes a scalar containing ascii text as an argument
+and returns a reference to an array of sentences that the text has been split
+into. Returned sentences will be trimmed (beginning and end of sentence) of
+white space. Strings with no alpha-numeric characters in them, won't be
+returned as sentences.
 
 =item add_acronyms( @acronyms )
 
-This function is used for adding acronyms not supported by this code.  Please see `Acronym/Abbreviations list' section for the abbreviations already supported by this module.
+This function is used for adding acronyms not supported by this code.Note that
+acronyms are seaerched for on a case insensive basis.
 
-=item get_acronyms(	)
+Please see`Acronym/Abbreviations list' section for the abbreviations already
+supported by this module.
+
+=item get_acronyms( )
 
 This function will return the defined list of acronyms.
 
@@ -55,16 +75,19 @@ This function will return the defined list of acronyms.
 
 This function replaces the predefined acroym list with the given list.
 
-=item get_EOS(	)
+=item get_EOS( )
 
-This function returns the value of the string used to mark the end of sentence. You might want to see what it is, and to make sure your text doesn't contain it. You can use set_EOS() to alter the end-of-sentence string to whatever you desire.
+This function returns the value of the string used to mark the end of sentence.
+You might want to see what it is, and to make sure your text doesn't contain it.
+You can use set_EOS() to alter the end-of-sentence string to whatever you
+desire.
 
 =item set_EOS( $new_EOS_string )
 
 This function alters the end-of-sentence string used to mark the end of sentences. 
 
 =item set_locale( $new_locale )
-Revceives language locale in the form language.country.character-set
+Receives language locale in the form language.country.character-set
 for example:
 	"fr_CA.ISO8859-1"
 for Canadian French using character set ISO8859-1.
@@ -73,7 +96,9 @@ Returns a reference to a hash containing the current locale formatting values.
 Returns undef if got undef.
 
 
-The following will set the LC_COLLATE behaviour to Argentinian Spanish. NOTE: The naming and avail ability of locales depends on your operating sys tem. Please consult the perllocale manpage for how to find out which locales are available in your system.
+The following will set the LC_COLLATE behaviour to Argentinian Spanish.
+NOTE: The naming and availability of locales depends on your operating sysem.
+Please consult the perllocale manpage for how to find out which locales are available in your system.
 
 $loc = set_locale( "es_AR.ISO8859-1" );
 
@@ -81,6 +106,8 @@ This actually does this:
 
 $loc = setlocale( LC_ALL, "es_AR.ISO8859-1" );
 
+=back
+
 =head1 Acronym/Abbreviations list
 
 You can use the get_acronyms() function to get acronyms.
@@ -90,10 +117,11 @@ If I come across a good general-purpose list - I'll incorporate it into this mod
 Feel free to suggest such lists. 
 
 =head1 FUTURE WORK
-[1] Object Oriented like usage
-[2] Supporting more than just English/French
-[3] Code optimization. Currently everything is RE based and not so optimized RE
-[4] Possibly use more semantic heuristics for detecting a beginning of a sentence
+
+	[1] Object Oriented like usage
+	[2] Supporting more than just English/French
+	[3] Code optimization. Currently everything is RE based and not so optimized RE
+	[4] Possibly use more semantic heuristics for detecting a beginning of a sentence
 
 =head1 SEE ALSO
 
@@ -101,11 +129,13 @@ Feel free to suggest such lists.
 
 =head1 AUTHOR
 
-Shlomo Yona E<lt>Shlomo.Yona@Siftology.comE<gt>
+Shlomo Yona shlomo@cs.haifa.ac.il
+
+Currently being maintained by Kim Ryan, kimryan at CPAN d o t org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001, 2002 Shlomo Yona. All rights reserved.
+Copyright (c) 2001-2015 Shlomo Yona. All rights reserved.
 
 This library is free software. 
 You can redistribute it and/or modify it under the same terms as Perl itself.  
@@ -124,15 +154,16 @@ You can redistribute it and/or modify it under the same terms as Perl itself.
 # Pragmas
 #
 #==============================================================================
-require 5.005_03;
+
 use strict;
-use POSIX qw(locale_h);
+use warnings;
+use POSIX qw(locale_h setlocale);
 #==============================================================================
 #
 # Modules
 #
 #==============================================================================
-require Exporter;
+use Exporter;
 
 #==============================================================================
 #
@@ -141,44 +172,54 @@ require Exporter;
 #==============================================================================
 use vars qw/$VERSION @ISA @EXPORT_OK $EOS $LOC $AP $P $PAP @ABBREVIATIONS/;
 use Carp qw/cluck/;
+use English;
 
-$VERSION = '0.24';
+our $VERSION = '0.26';
 
 # LC_CTYPE now in locale "French, Canada, codeset ISO 8859-1"
-$LOC=setlocale(LC_CTYPE, "fr_CA.ISO8859-1"); 
+our $LOC;
+if ($OSNAME ne 'android') {
+	# Call POSIX function
+	$LOC=  setlocale(LC_CTYPE, "fr_CA.ISO8859-1");
+}
+
+ 
 use locale;
 
 @ISA = qw( Exporter );
-@EXPORT_OK = qw( get_sentences 
-		add_acronyms get_acronyms set_acronyms
-		get_EOS set_EOS);
+@EXPORT_OK = qw( get_sentences add_acronyms get_acronyms set_acronyms get_EOS set_EOS set_locale);		
 
-$EOS="\001";
-$P = q/[\.!?]/;			## PUNCTUATION
-$AP = q/(?:'|"||\)|\]|\})?/;	## AFTER PUNCTUATION
-$PAP = $P.$AP;
+our $EOS="\001";
 
-my @PEOPLE = ( 'jr', 'mr', 'mrs', 'ms', 'dr', 'prof', 'sr', "sens?", "reps?", 'gov',
-		"attys?", 'supt',  'det', 'rev' );
+our $P = q/[\.!?]/;			## PUNCTUATION
+#$AP = q/(?:'|"|?|\)|\]|\})?/;	## AFTER PUNCTUATION Kim change
+$AP =  q/(?:'|"|\?|\)|\]|\})?/;	## AFTER PUNCTUATION
+our $PAP = $P.$AP;
 
+my @PEOPLE = qw( jr mr mrs ms dr prof sr sens? reps? gov 
+		attys? supt  det rev );
 
-my @ARMY = ( 'col','gen', 'lt', 'cmdr', 'adm', 'capt', 'sgt', 'cpl', 'maj' );
-my @INSTITUTES = ( 'dept', 'univ', 'assn', 'bros' );
-my @COMPANIES = ( 'inc', 'ltd', 'co', 'corp' );
-my @PLACES = ( 'arc', 'al', 'ave', "blv?d", 'cl', 'ct', 'cres', 'dr', "expy?",
-		'dist', 'mt', 'ft',
-		"fw?y", "hwa?y", 'la', "pde?", 'pl', 'plz', 'rd', 'st', 'tce',
-		'Ala' , 'Ariz', 'Ark', 'Cal', 'Calif', 'Col', 'Colo', 'Conn',
-		'Del', 'Fed' , 'Fla', 'Ga', 'Ida', 'Id', 'Ill', 'Ind', 'Ia',
-		'Kan', 'Kans', 'Ken', 'Ky' , 'La', 'Me', 'Md', 'Is', 'Mass', 
-		'Mich', 'Minn', 'Miss', 'Mo', 'Mont', 'Neb', 'Nebr' , 'Nev',
-		'Mex', 'Okla', 'Ok', 'Ore', 'Penna', 'Penn', 'Pa'  , 'Dak',
-		'Tenn', 'Tex', 'Ut', 'Vt', 'Va', 'Wash', 'Wis', 'Wisc', 'Wy',
-		'Wyo', 'USAFA', 'Alta' , 'Man', 'Ont', 'Qu', 'Sask', 'Yuk');
-my @MONTHS = ('jan','feb','mar','apr','may','jun','jul','aug','sep','oct','nov','dec','sept');
-my @MISC = ( 'vs', 'etc', 'no', 'esp' );
+my @ARMY = qw( col gen lt cmdr adm capt sgt cpl maj );
+my @INSTITUTES = qw( dept univ assn bros );
+my @COMPANIES = qw( inc ltd co corp );
+my @PLACES =
+qw(
+	arc al ave blv?d cl ct cres dr expy? 
+	dist mt ft 
+	fw?y hwa?y la pde? pl plz rd st tce 
+	Ala  Ariz Ark Cal Calif Col Colo Conn 
+	Del Fed  Fla Ga Ida Id Ill Ind Ia 
+	Kan Kans Ken Ky  La Me Md Is Mass 
+	Mich Minn Miss Mo Mont Neb Nebr  Nev 
+	Mex Okla Ok Ore Penna Penn Pa  Dak 
+	Tenn Tex Ut Vt Va Wash Wis Wisc Wy 
+	Wyo USAFA Alta  Man Ont Qu? Sask Yuk
+);
+my @MONTHS = qw(jan feb mar apr may jun jul aug sep oct nov dec sept);
+my @MISC = qw(no esp );
+my @LATIN = qw(vs etc );
 
-@ABBREVIATIONS = (@PEOPLE, @ARMY, @INSTITUTES, @COMPANIES, @PLACES, @MONTHS, @MISC ); 
+our @ABBREVIATIONS = (@PEOPLE, @ARMY, @INSTITUTES, @COMPANIES, @PLACES, @MONTHS, @MISC, @LATIN ); 
 
 
 #==============================================================================
@@ -189,9 +230,9 @@ my @MISC = ( 'vs', 'etc', 'no', 'esp' );
 
 #------------------------------------------------------------------------------
 # get_sentences - takes text input and splits it into sentences.
-# A regular expression cuts viciously the text into sentences, 
+# A regular expression viciously cuts the text into sentences, 
 # and then a list of rules (some of them consist of a list of abbreviations)
-# is applied on the marked text in order to fix end-of-sentence markings on 
+# are applied on the marked text in order to fix end-of-sentence markings in 
 # places which are not indeed end-of-sentence.
 #------------------------------------------------------------------------------
 sub get_sentences {
@@ -213,28 +254,28 @@ sub add_acronyms {
 }
 
 #------------------------------------------------------------------------------
-# get_acronyms - get defined list of acronyms.
+# get_acronyms - get list of defined acronyms.
 #------------------------------------------------------------------------------
 sub get_acronyms {
 	return @ABBREVIATIONS;
 }
 
 #------------------------------------------------------------------------------
-# set_acronyms - run over the predefined acronyms list with your own list.
+# set_acronyms - replace the predefined acronyms list with your own list.
 #------------------------------------------------------------------------------
 sub set_acronyms {
 	@ABBREVIATIONS=@_;
 }
 
 #------------------------------------------------------------------------------
-# get_EOS - get the value of the $EOS (end-of-sentence mark).
+# get_EOS - get the value of the $EOS variable (end-of-sentence mark).
 #------------------------------------------------------------------------------
 sub get_EOS {
 	return $EOS;
 }
 
 #------------------------------------------------------------------------------
-# set_EOS - set the value of the $EOS (end-of-sentence mark).
+# set_EOS - set the value of the $EOS variable (end-of-sentence mark).
 #------------------------------------------------------------------------------
 sub set_EOS {
 	my ($new_EOS) = @_;
@@ -246,32 +287,29 @@ sub set_EOS {
 }
 
 #------------------------------------------------------------------------------
+
 # set_locale - set the value of the locale.
 #
-#		Revceives language locale in the form
-#			language.country.character-set
-#		for example:
-#				"fr_CA.ISO8859-1"
-#		for Canadian French using character set ISO8859-1.
+# Receieves language locale in the form
+#	language.country.character-set
+# for example:
+#	"fr_CA.ISO8859-1"
+# for Canadian French using character set ISO8859-1.
 #
-#		Returns a reference to a hash containing the current locale 
-#		formatting values.
-#		Returns undef if got undef.
+# Returns a reference to a hash containing the current locale formatting values.
+# Returns undef if got undef.
 #
+#	The following will set the LC_ALL behaviour to Argentinian Spanish.
+#	NOTE: The naming and availability of locales depends on your operating system.
+#	Please consult the perllocale manpage for how to find out which locales are
+#	available in your system.
 #
-#               The following will set the LC_COLLATE behaviour to
-#               Argentinian Spanish. NOTE: The naming and avail
-#               ability of locales depends on your operating sys
-#               tem. Please consult the perllocale manpage for how
-#               to find out which locales are available in your
-#               system.
+#		$loc = set_locale( "es_AR.ISO8859-1" );
 #
-#                       $loc = set_locale( "es_AR.ISO8859-1" );
+# This actually does this:
 #
-#
-#		This actually does this:
-#
-#			$loc = setlocale( LC_ALL, "es_AR.ISO8859-1" );
+#	$loc = setlocale( LC_ALL, "es_AR.ISO8859-1" ); # NOTE, but actually does LC_CTYPE, should be LC_COLLATE?
+
 #------------------------------------------------------------------------------
 sub set_locale {
 	my ($new_locale) = @_;
@@ -279,8 +317,15 @@ sub set_locale {
 		cluck "Won't set locale to undefined value!\n";
 		return undef;
 	}
-	$LOC = setlocale(LC_CTYPE, $new_locale); 
-	return $LOC;
+	
+	if ($OSNAME ne 'android') {
+		# Call POSIX function
+		$LOC = setlocale(LC_CTYPE, $new_locale);
+		return $LOC;
+	}
+	else {
+		return undef;	
+	}	
 }
 
 
